# Tasks: [FEATURE NAME]

<!--
Language: Generate this document in the language specified in .codexspec/config.yml
If not configured, use English.
-->

## 1. <!-- Task Group Name -->

- [ ] 1.1 <!-- Task description -->
- [ ] 1.2 <!-- Task description -->
- [ ] 1.3 <!-- Task description -->

## 2. <!-- Task Group Name -->

- [ ] 2.1 <!-- Task description -->
- [ ] 2.2 <!-- Task description -->
- [ ] 2.3 <!-- Task description -->

## 3. <!-- Task Group Name -->

- [ ] 3.1 <!-- Task description -->
- [ ] 3.2 <!-- Task description -->
- [ ] 3.3 <!-- Task description -->

## Dependencies

```
1.1 -> 1.2 -> 2.1 -> 2.2 -> 3.1
              |
              v
             2.3 -> 3.2
```

## Notes

- <!-- Additional notes -->
